@@ -13,8 +13,6 @@
 
 #define UNSTABLE_POPPLER_QT4
 
-#include "synctex/synctex_parser.h"
-
 #include <poppler-qt4.h>
 
 #include <qbitarray.h>
@@ -64,7 +62,7 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
         Okular::Document::OpenResult loadDocumentFromDataWithPassword( const QByteArray & fileData, QVector<Okular::Page*> & pagesVector, const QString & password );
         void loadPages(QVector<Okular::Page*> &pagesVector, int rotation=-1, bool clear=false);
         // [INHERITED] document information
-        const Okular::DocumentInfo * generateDocumentInfo();
+        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const;
         const Okular::DocumentSynopsis * generateDocumentSynopsis();
         Okular::FontInfo::List fontsForPage( int page );
         const QList<Okular::EmbeddedFile*> * embeddedFiles() const;
@@ -104,7 +102,6 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
 
     protected slots:
         void requestFontData(const Okular::FontInfo &font, QByteArray *data);
-        const Okular::SourceReference * dynamicSourceReference( int pageNr, double absX, double absY );
         Okular::Generator::PrintError printError() const;
 
     private:
@@ -120,10 +117,6 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
         void addFormFields( Poppler::Page * popplerPage, Okular::Page * page );
         // load the source references from a pdfsync file
         void loadPdfSync( const QString & fileName, QVector<Okular::Page*> & pagesVector );
-        // init the synctex parser if a synctex file exists
-        void initSynctexParser( const QString& filePath );
-        // search document for source reference
-        void fillViewportFromSourceReference( Okular::DocumentViewport & viewport, const QString & reference ) const;
 
         Okular::TextPage * abstractTextPage(const QList<Poppler::TextBox*> &text, double height, double width, int rot);
 
@@ -137,8 +130,6 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
 
 
         // misc variables for document info and synopsis caching
-        bool docInfoDirty;
-        Okular::DocumentInfo docInfo;
         bool docSynopsisDirty;
         Okular::DocumentSynopsis docSyn;
         mutable bool docEmbeddedFilesDirty;
@@ -151,8 +142,6 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
 
         QPointer<PDFOptionsPage> pdfOptionsPage;
         
-        synctex_scanner_t synctex_scanner;
-        
         PrintError lastPrintError;
 };
 
